@@ -43,7 +43,7 @@ class FacebookTestCase(TestCase):
                 self.test_user = TestUser.objects.get(name=self.facebook_test_user)
                 setup_facebook_test_client.send(sender=None, client=self.client, signed_request=_create_signed_request(
                     settings.FACEBOOK_APPLICATION_SECRET_KEY,
-                    self.test_user.facebook_id,
+                    str(self.test_user.facebook_id),
                     oauth_token=self.test_user.access_token,
                 ))
             except TestUser.DoesNotExist:
